@@ -1,4 +1,3 @@
-
 {-|
 Module      : $header$
 Copyright   : (c) Laurent P René de Cotret, 2020
@@ -12,15 +11,19 @@ The external use of content from this module is discouraged.
 -}
 
 module Text.Pandoc.Filter.Plot.Internal (
-      module Text.Pandoc.Filter.Plot.Types
-    , module Text.Pandoc.Filter.Plot.Renderers
+      module Text.Pandoc.Filter.Plot.Renderers
     , module Text.Pandoc.Filter.Plot.Scripting
     , module Text.Pandoc.Filter.Plot.Parse
     , module Text.Pandoc.Filter.Plot.Configuration
+    , module Text.Pandoc.Filter.Plot.Clean
+    , module Text.Pandoc.Filter.Plot.Monad
+    , module Text.Pandoc.Filter.Plot.Embed
  ) where
 
-import           Text.Pandoc.Filter.Plot.Parse
-import           Text.Pandoc.Filter.Plot.Renderers
-import           Text.Pandoc.Filter.Plot.Scripting
-import           Text.Pandoc.Filter.Plot.Types
-import           Text.Pandoc.Filter.Plot.Configuration
\ No newline at end of file
+import Text.Pandoc.Filter.Plot.Parse
+import Text.Pandoc.Filter.Plot.Renderers
+import Text.Pandoc.Filter.Plot.Scripting
+import Text.Pandoc.Filter.Plot.Configuration
+import Text.Pandoc.Filter.Plot.Clean
+import Text.Pandoc.Filter.Plot.Monad
+import Text.Pandoc.Filter.Plot.Embed
\ No newline at end of file
