@@ -26,15 +26,24 @@ mathematicaSupportedSaveFormats :: [SaveFormat]
 mathematicaSupportedSaveFormats = [PNG, PDF, SVG, JPG, EPS, GIF, TIF]
 
 
-mathematicaCommand :: Configuration -> FigureSpec -> FilePath -> Text
-mathematicaCommand Configuration{..} _ fp = [st|#{mathematicaExe} -script #{fp}|]
+mathematicaCommand :: OutputSpec -> Text -> Text
+mathematicaCommand OutputSpec{..} exe = [st|#{exe} -script "#{oScriptPath}"|]
 
 
-mathematicaAvailable :: Configuration -> IO Bool
-mathematicaAvailable Configuration{..} = commandSuccess [st|#{mathematicaExe} -h|] -- TODO: test this
+mathematicaAvailable :: PlotM Bool
+mathematicaAvailable = do
+    mexe <- executable Mathematica
+    case mexe of 
+        Nothing -> return False
+        Just (Executable dir exe) -> 
+            commandSuccess dir [st|#{exe} -h|] -- TODO: test this
 
 
 mathematicaCapture :: FigureSpec -> FilePath -> Script
-mathematicaCapture FigureSpec{..} fname = [st|
-Export["#{fname}", %, show saveFormat]
+mathematicaCapture = appendCapture mathematicaCaptureFragment
+
+
+mathematicaCaptureFragment :: FigureSpec -> FilePath -> Script
+mathematicaCaptureFragment FigureSpec{..} fname = [st|
+Export["#{fname}", %, #{show saveFormat}, ImageResolution -> #{dpi}]
 |]
