@@ -27,15 +27,24 @@ octaveSupportedSaveFormats :: [SaveFormat]
 octaveSupportedSaveFormats = [PNG, PDF, SVG, JPG, EPS, GIF, TIF]
 
 
-octaveCommand :: Configuration -> FigureSpec -> FilePath -> Text
-octaveCommand Configuration{..} _ fp = [st|#{octaveExe} --no-gui --no-window-system #{fp}|]
+octaveCommand :: OutputSpec -> Text -> Text
+octaveCommand OutputSpec{..} exe = [st|#{exe} --no-gui --no-window-system "#{oScriptPath}"|]
 
 
-octaveAvailable :: Configuration -> IO Bool
-octaveAvailable Configuration{..} = commandSuccess [st|#{octaveExe} -h|]
+octaveAvailable :: PlotM Bool
+octaveAvailable = do
+    mexe <- executable Octave
+    case mexe of 
+        Nothing -> return False
+        Just (Executable dir exe) -> 
+            commandSuccess dir [st|#{exe} -h|]
 
 
 octaveCapture :: FigureSpec -> FilePath -> Script
-octaveCapture FigureSpec{..} fname = [st|
+octaveCapture = appendCapture octaveCaptureFragment
+
+
+octaveCaptureFragment :: FigureSpec -> FilePath -> Script
+octaveCaptureFragment _ fname = [st|
 saveas(gcf, '#{fname}')
 |]
